@@ -28,7 +28,7 @@ from .exceptions import InvalidSchema
 from .filters import should_skip_by_tag, should_skip_endpoint, should_skip_method
 from .models import Endpoint, empty_object
 from .types import Filter, Hook, NotSet
-from .utils import NOT_SET, StringDatesYAMLLoader
+from .utils import NOT_SET, GenericResponse, StringDatesYAMLLoader
 
 
 def load_file_impl(location: str, opener: Callable) -> Dict[str, Any]:
@@ -166,9 +166,14 @@ class BaseSchema(Mapping):
         key = HookLocation[place]
         return self.hooks.get(key)
 
+    def get_content_types(self, endpoint: Endpoint, response: GenericResponse) -> List[str]:
+        """Content types available for this endpoint."""
+        raise NotImplementedError
+
 
 class SwaggerV20(BaseSchema):
     nullable_name = "x-nullable"
+    operations: Tuple[str, ...] = ("get", "put", "post", "delete", "options", "head", "patch")
 
     def __repr__(self) -> str:
         info = self.raw_schema["info"]
@@ -206,8 +211,7 @@ class SwaggerV20(BaseSchema):
                 for method, definition in methods.items():
                     # Only method definitions are parsed
                     if (
-                        method == "parameters"
-                        or method.startswith("x-")
+                        method not in self.operations
                         or should_skip_method(method, self.method)
                         or should_skip_by_tag(definition.get("tags"), self.tag)
                     ):
@@ -318,9 +322,16 @@ class SwaggerV20(BaseSchema):
     def _get_response_schema(self, definition: Dict[str, Any]) -> Optional[Dict[str, Any]]:
         return definition.get("schema")
 
+    def get_content_types(self, endpoint: Endpoint, response: GenericResponse) -> List[str]:
+        produces = endpoint.definition.get("produces", None)
+        if produces:
+            return produces
+        return self.raw_schema.get("produces", [])
+
 
 class OpenApi30(SwaggerV20):  # pylint: disable=too-many-ancestors
     nullable_name = "nullable"
+    operations = SwaggerV20.operations + ("trace",)
 
     @property
     def spec_version(self) -> str:
@@ -363,12 +374,14 @@ class OpenApi30(SwaggerV20):  # pylint: disable=too-many-ancestors
     def add_parameter(self, container: Optional[Dict[str, Any]], parameter: Dict[str, Any]) -> Dict[str, Any]:
         container = super().add_parameter(container, parameter)
         if "example" in parameter["schema"]:
-            container["example"] = {parameter["name"]: parameter["schema"]["example"]}
+            examples = container.setdefault("example", {})  # examples should be merged together
+            examples[parameter["name"]] = parameter["schema"]["example"]
         # https://github.com/OAI/OpenAPI-Specification/blob/master/versions/3.0.2.md#parameter-object
         # > Furthermore, if referencing a schema which contains an example,
         # > the example value SHALL override the example provided by the schema
         if "example" in parameter:
-            container["example"] = {parameter["name"]: parameter["example"]}
+            examples = container.setdefault("example", {})  # examples should be merged together
+            examples[parameter["name"]] = parameter["example"]
         return container
 
     def process_cookie(self, endpoint: Endpoint, parameter: Dict[str, Any]) -> None:
@@ -396,6 +409,15 @@ class OpenApi30(SwaggerV20):  # pylint: disable=too-many-ancestors
             return option["schema"]
         return None
 
+    def get_content_types(self, endpoint: Endpoint, response: GenericResponse) -> List[str]:
+        try:
+            responses = endpoint.definition["responses"]
+        except KeyError:
+            # Possible to get if `validate_schema=False` is passed during schema creation
+            raise InvalidSchema("Schema parsing failed. Please check your schema.")
+        definitions = responses.get(str(response.status_code), {}).get("content", {})
+        return list(definitions.keys())
+
 
 def get_common_parameters(methods: Dict[str, Any]) -> List[Dict[str, Any]]:
     """Common parameters are deep copied from the methods definitions.
